import type { LicenseRecord, TikiSdk, PayableRecord, ReceiptRecord } from "@mytiki/tiki-sdk-capacitor";
import type { Config } from "@/config";
import type { Receipt } from "@mytiki/capture-receipt-capacitor";
/**
 * A service class for interacting with the TIKI publish plugin.
 */
export declare class Publish {
    readonly plugin: TikiSdk;
    private readonly config;
    private _id?;
    private _license?;
    constructor(config: Config);
    /**
     * Initializes the SDK service for the specified user.
     * Do not call direct. Prefer {@link TikiService.initialize}.
     * @param id - The user's unique identifier to initialize the SDK for.
     * @returns A Promise that resolves when the initialization is complete.
     */
    initialize(id: string): Promise<void>;
    /**
     * Gets the user's identifier for the instance.
     * @throws Error if Tiki is not initialized. First call `.initialize()`.
     * @returns The user's identifier for the instance.
     */
    get id(): string;
    /**
     * Gets current license record associated with the instance.
     * @returns A Promise that resolves with the license record or undefined if not found.
     */
    getLicense(): Promise<LicenseRecord | undefined>;
    /**
     * Creates a new license for the SDK service using the {@link Config}.
     * @returns A Promise that resolves when the license creation is complete.
     */
    createLicense(): Promise<void>;
    /**
     * Gets an array of payable records associated with the current license.
     * @returns A Promise that resolves with an array of payable records.
     */
    getPayables(): Promise<PayableRecord[]>;
    /**
     * Creates a new payable record for the current license.
     * @param amount - The total amount owed.
     * @param description - An optional description of the payable event.
     * @param reference - An optional reference for the payable.
     * @returns A Promise that resolves with the created payable record or undefined.
     */
    createPayable(amount: number, description?: string | undefined, reference?: string): Promise<PayableRecord | undefined>;
    /**
     * Creates a new receipt record for the latest payable.
     * @param amount - The amount paid/redeemed.
     * @param description - An optional description of the payout event.
     * @returns A Promise that resolves with the created receipt record or undefined.
     */
    createReceipt(amount: number, description?: string): Promise<ReceiptRecord | undefined>;
    getReceipts(payables?: PayableRecord[]): Promise<ReceiptRecord[]>;
    publish(receipt: Receipt): Promise<void>;
    balance(): Promise<number>;
    logout(): void;
}
